.. image:: https://api.codeclimate.com/v1/badges/34cf134656b57fd5ed21/maintainability
   :target: https://codeclimate.com/github/snake-soft/django-git-changelog/maintainability
   :alt: Maintainability

====================
Changelog for Django
====================

This needs some work to be used in productive.


Installation
------------

Install using pip:

.. code-block:: bash

	pip install django-changelog


.. code-block:: python

   # settings.py
   INSTALLED_APPS = [
       # ...
       'changelog.apps.ChangelogConfig',
       # ...
   ]
